﻿using UnityEngine;
using System;
using System.Text;
using System.Text.RegularExpressions;
using System.Collections.Generic;
using System.Threading;

//using BuglyUnity;

public class Demo : MonoBehaviour
{

    private const string BuglyAppIDForiOS = "900001055";
    private const string BuglyAppIDForAndroid = "900001191";

    void InitBuglySDK ()
    {

        // TODO NOT Required. Set the crash reporter type and log to report
        // BuglyAgent.ConfigCrashReporter (0, 2);

        // TODO NOT Required. Enable debug log print, please set false for release version
        BuglyAgent.ConfigDebugMode (true);

        // TODO NOT Required. Register log callback with 'BuglyAgent.LogCallbackDelegate' to replace the 'Application.RegisterLogCallback(Application.LogCallback)'
        // BuglyAgent.RegisterLogCallback (CallbackDelegate.Instance.OnApplicationLogCallbackHandler);

        BuglyAgent.ConfigDefault ("Bugly", null, "ronnie", 0);

        #if UNITY_IPHONE || UNITY_IOS
        BuglyAgent.InitWithAppId (BuglyAppIDForiOS);
        #elif UNITY_ANDROID
        BuglyAgent.InitWithAppId (BuglyAppIDForAndroid);
        #endif

        // TODO Required. If you do not need call 'InitWithAppId(string)' to initialize the sdk(may be you has initialized the sdk it associated Android or iOS project),
        // please call this method to enable c# exception handler only.
        BuglyAgent.EnableExceptionHandler ();

        // TODO NOT Required. If you need to report extra data with exception, you can set the extra handler
        // BuglyAgent.SetLogCallbackExtrasHandler (MyLogCallbackExtrasHandler);

        BuglyAgent.PrintLog (LogSeverity.LogInfo, "Init the bugly sdk");
    }

    // Extra data handler to packet data and report them with exception.
    // Please do not do hard work in this handler 
    Dictionary<string, string> MyLogCallbackExtrasHandler ()
    {
        // TODO Test log, please do not copy it
        BuglyAgent.PrintLog (LogSeverity.Log, "extra handler");

        // TODO Sample code, please do not copy it
        Dictionary<string, string> extras = new Dictionary<string, string> ();
        extras.Add ("ScreenSolution", string.Format ("{0}x{1}", Screen.width, Screen.height));
        extras.Add ("deviceModel", SystemInfo.deviceModel);
        extras.Add ("deviceName", SystemInfo.deviceName);
        extras.Add ("deviceType", SystemInfo.deviceType.ToString ());

        extras.Add ("deviceUId", SystemInfo.deviceUniqueIdentifier);
        extras.Add ("gDId", string.Format ("{0}", SystemInfo.graphicsDeviceID));
        extras.Add ("gDName", SystemInfo.graphicsDeviceName);
        extras.Add ("gDVdr", SystemInfo.graphicsDeviceVendor);
        extras.Add ("gDVer", SystemInfo.graphicsDeviceVersion);
        extras.Add ("gDVdrID", string.Format ("{0}", SystemInfo.graphicsDeviceVendorID));

        extras.Add ("graphicsMemorySize", string.Format ("{0}", SystemInfo.graphicsMemorySize));
        extras.Add ("systemMemorySize", string.Format ("{0}", SystemInfo.systemMemorySize));
        extras.Add ("UnityVersion", Application.unityVersion);
 
        BuglyAgent.PrintLog (LogSeverity.LogInfo, "Package extra data");
        return extras;
    }

    // Use this for initialization
    void Start ()
    {  
        BuglyAgent.PrintLog (LogSeverity.LogInfo, "Demo Start()");

        SetupGUIStyle ();

        InitBuglySDK ();

        BuglyAgent.PrintLog (LogSeverity.LogWarning, "Init bugly sdk done");
        // set tag
#if UNITY_ANDROID
            BuglyAgent.SetScene (3450);
#else
        BuglyAgent.SetScene (3261);
#endif

    }

    // Update is called once per frame
    void Update ()
    {
        #if UNITY_ANDROID
        //当用户按下手机的返回键或home键退出游戏
        if (Input.GetKeyDown(KeyCode.Escape) || Input.GetKeyDown(KeyCode.Home))
        {
            Application.Quit();
        }
        // 按返回键退出应用
        if (Input.GetKeyDown (KeyCode.Escape)) {
            Application.Quit ();
        }
        #endif

    }

    void OnGUI ()
    {
        StyledGUI ();

        // set the base area
        GUILayout.BeginArea (new Rect (0, 0, Screen.width, Screen.height));

        GUILayout.BeginVertical ();

        // set the title bar
        GUILayout.Space (20);
        GUILayout.BeginHorizontal ();
        GUILayout.FlexibleSpace ();
        GUILayout.Label ("Bugly Unity Demo", styleTitle);
        GUILayout.FlexibleSpace ();
        GUILayout.EndHorizontal ();

        GUILayout.Space (20);

        // set layout
        GUILayout.BeginVertical ();
        GUILayout.Label ("Uncaught Exceptions:", styleContent);
        GUILayout.Space (20);

        scrollPosition = GUILayout.BeginScrollView (scrollPosition, GUILayout.Width (Screen.width), GUILayout.Height (Screen.height - 100));

//      GUILayout.BeginArea (new Rect(20,100, Screen.width - 20, Screen.height));
        GUILayout.BeginHorizontal ();
        GUILayout.Space (40);
        selGridIntCurrent = GUILayout.SelectionGrid (selGridIntCurrent, selGridItems, 2);
        GUILayout.Space (40);
        GUILayout.EndHorizontal ();
//              GUILayout.EndArea ();
        GUILayout.EndScrollView ();

        if (selGridIntCurrent != selGridIntDefault) {
            selGridIntDefault = selGridIntCurrent;

            TrigException (selGridIntCurrent);
        }

        GUILayout.EndVertical ();

        GUILayout.EndVertical ();
        GUILayout.EndArea ();

    }

    private void TrigException (int selGridInt)
    {
        BuglyAgent.PrintLog (LogSeverity.LogWarning, "Trigge Exception: {0}", selGridInt);

        switch (selGridInt) {
        case 0:
            throwException (new System.Exception ("Non-fatal error, an base C# exception"));
            break;
        case 1:
            throwException (new System.SystemException ("Fatal error, a system exception"));
            break;
        case 2:
            throwException (new System.ApplicationException ("Fatal error, an application exception"));
            break;
        case 3:
            throwException (new System.ArgumentException (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 4:
            throwException (new System.FormatException (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 5: // ignore
            break;
        case 6:
            throwException (new System.MemberAccessException (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 7:
            throwException (new System.FieldAccessException (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 8:
            throwException (new System.MethodAccessException (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 9:
            throwException (new System.MissingMemberException (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 10:
            throwException (new System.MissingMethodException (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 11:
            throwException (new System.MissingFieldException (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 12:
            throwException (new System.IndexOutOfRangeException (string.Format ("Non-Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 13:
            throwException (new System.ArrayTypeMismatchException (string.Format ("Non-Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 14:
            throwException (new System.RankException (string.Format ("Non-Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 15:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
            try {
                throwException (new System.Exception (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            } catch (System.Exception e) {
                BuglyAgent.ReportException (e, "Caught an exception.");
            }
            break;
        case 21:
            throwException (new System.ArithmeticException (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 22:
            throwException (new System.NotFiniteNumberException (string.Format ("Fatal error, {0} ", selGridItems [selGridInt])));
            break;
        case 23:
            int i = 0;
            i = 2 / i;
            break;
        case 24:
            throwException (new System.OutOfMemoryException ("Fatal error, OOM"));
            break;
        case 25:
            findGameObject ();
            break;
        case 26:
            System.Exception excep = null;
            System.IndexOutOfRangeException iore = (System.IndexOutOfRangeException)excep;
            System.Console.Write ("" + iore);
            break;
        case 27:
            findGameObjectByTag ();
            break;
        case 28:
            DoCrash ();
            break;
        case 29:
        default:
            try {
                throwException (new System.OutOfMemoryException ("Fatal error, out of memory"));
            } catch (System.Exception e) {
                UnityEngine.Debug.LogException (e);
            }
            break;
        }

    }

    private void findGameObjectByTag ()
    {
        System.Console.Write ("it will throw UnityException");
        GameObject go = GameObject.FindWithTag ("test");

        string gName = go.name;
        System.Console.Write (gName);
    }

    private void findGameObject ()
    {
        System.Console.Write ("it will throw NullReferenceException");

        GameObject go = GameObject.Find ("test");
        string gName = go.name;

        System.Console.Write (gName);
    }
    
    private void throwException (Exception e)
    {
        if (e == null)
            return;

        BuglyAgent.PrintLog (LogSeverity.LogWarning, "Throw exception: {0}", e.ToString ());

        testDeepFrame (e);
    }

    private void testDeepFrame (Exception e)
    {
    
        throw e;
    }

    private void DoCrash ()
    {
        System.Console.Write ("it will Crash...");

//      string[] strs = new string[100000000];
//      int len = strs [0].Length;
        DoCrash ();
    }

    private int selGridIntCurrent = 5;
    private int selGridIntDefault = -1;
    private Vector2 scrollPosition = Vector2.zero;
    private string[] selGridItems = new string[] {"Exception","SystemException","ApplicationException",
        "ArgumentException","FormatException","...",
        "MemberAccessException","FileAccessException","MethodAccessException","MissingMemberException","MissingMethodException","MissingFieldException",
        "IndexOutOfException","ArrayTypeMismatchException","RankException",
        "IOException","DirectionNotFoundException","FileNotFoundException","EndOfStreamException","FileLoadException","PathTooLongException",
        "ArithmeticException","NotFiniteNumberException","DivideByZeroException",
        "OutOfMemoryException","NullReferenceException","InvalidCastException","InvalidOperationException",
        "",""
    };
    private GUIStyle styleTitle;
    private GUIStyle styleContent;
    
    void SetupGUIStyle ()
    {
        styleTitle = new GUIStyle ();
        styleTitle.fontSize = 28;
        styleTitle.fontStyle = FontStyle.Bold;
        
        styleContent = new GUIStyle ();
        styleContent.fontSize = 20;
        styleContent.fontStyle = FontStyle.Italic;
    }

    private static float StandardScreenWidth = 640.0f;
    private static float StandardScreenHeight = 960.0f;
    private float guiRatioX;
    private float guiRatioY;
    private float screenWidth;
    private float screenHeight;
    private Vector3 scaleGUIs;

    void Awake ()
    {
        BuglyAgent.DebugLog ("Demo.Awake()", "Screen: {0} x {1}", Screen.width, Screen.height);

        screenWidth = Screen.width;
        screenHeight = Screen.height;
        
        guiRatioX = (float)(screenWidth / StandardScreenWidth * 1.0f);
        guiRatioY = (float)(screenHeight / StandardScreenHeight * 1.0f);
        
        scaleGUIs = new Vector3 (guiRatioX, guiRatioY, 1.0f);
    }
    
    public void StyledGUI ()
    {
//        GUI.matrix = Matrix4x4.TRS (new Vector3(scaleGUIs.x, scaleGUIs.y, 0.0f), Quaternion.identity, scaleGUIs);

        GUI.color = Color.gray;
        GUI.skin.label.fontSize = 20;
        GUI.skin.button.fontSize = 20;
    }
}
